#
# spec file for package tupitube
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define	_qtdir    %{_libdir}/qt5/
%define	_tupibin  %{_libdir}/%{name}/bin
%define	_tupilib  %{_libdir}/%{name}
%define	_tupidata %{_datadir}/%{name}
Name:           tupitube
Version:        0.2.13
Release:        bp153.1.2
Summary:        2D vectorial/animation tool
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Graphics/Vector Editors
URL:            https://maefloresta.com
Source0:        https://sourceforge.net/projects/tupi2d/files/Source%20Code/tupitube.desk-%{version}.tar.gz
Patch1:         tupitube.libav.patch
# PATCH-FIX-OPENSUSE tupitube-pkgconfig.patch use pkgconfig whenver possible -- aloisio@gmx.com
Patch2:         tupitube-pkgconfig.patch
# PATCH-FIX-OPENSUSE tupitube-fix_quazip_namespace.patch
Patch3:         tupitube-fix_quazip_namespace.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libquazip-qt5-devel
BuildRequires:  pkgconfig
BuildRequires:  ruby
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.12.7
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  rubygem(pkg-config)
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libogg.so) --qf '%%{NAME} >= %%{VERSION}')
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libtheora.so) --qf '%%{NAME} >= %%{VERSION}')
Requires:       %{name}-plugins
Requires:       ffmpeg
Provides:       ktoon = %{version}
Obsoletes:      ktoon < %{version}
Provides:       tupi = %{version}
Obsoletes:      tupi < %{version}

%description
Tupitube is a design and authoring tool for digital artists
interested in 2D animation. Its source code is based on the KTooN
project.

Some of its main features are: basic illustration tools (shapes, fill,
text), gradient tools, onion skin, brushes editor, pencil with smoothness
support and a basic object library (for SVG files and raster images).

Using its modules of animation and reproduction, 2D projects can be exported
to several formats such as OGG, MPEG, AVI, MOV and SWF. Additionally, the
option of exporting image arrays as output is available.

%package        plugins
Summary:        Tupi plugins
Group:          Productivity/Graphics/Vector Editors
Requires:       %{name} = %{version}

%description    plugins
A design and authoring tool for 2D animation.

This package contains plugins for %{name}.

%prep
%setup -q -n tupitube.desk
%autopatch -p1

# remove executable bits
chmod -x COPYING README* launcher/tupitube.xml
find src -type f -exec chmod -x {} \;

%build
%configure \
	--with-qtdir=%{_qtdir} \
	--bindir=%{_tupibin} \
	--libdir=%{_tupilib} \
	--sharedir=%{_tupidata}

%make_build

%install
%make_install

# Create symbolic link
install -d %{buildroot}%{_bindir}
ln -s %{_tupibin}/%{name}.desk %{buildroot}%{_bindir}/%{name}
# Remove unneeded links
pushd %{buildroot}%{_tupilib}
for so in $(find . -maxdepth 1 -name \*.so); do
rm -f $so; done
popd
# SVG icon
install -Dm 0644 launcher/icons/icon.svg \
%{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
# fix icon name
mv %{buildroot}%{_datadir}/pixmaps/%{name}.desk.png \
%{buildroot}%{_datadir}/pixmaps/%{name}.png
# fix .desktop
sed -i -e '/^Exec/cExec=%{name}' -e '/^Icon/cIcon=%{name}' \
%{buildroot}%{_datadir}/applications/%{name}.desktop

%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc README*
%{_bindir}/%{name}
%{_tupibin}/
%dir %{_tupilib}
%{_tupilib}/*.so.*
%{_tupidata}/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%exclude %{_tupilib}/plugins

%files plugins
%dir %{_tupilib}/plugins
%{_tupilib}/plugins/*.so

%changelog
* Wed Mar 31 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.2.13, fixes (boo#1183763)
  * No changelog
- Add GPL-3.0-or-later license on account of the libqtmypaint
  plugin
- Change required Qt version to >= 5.12.7 in order to build on
  Backports/Leap 15.3
- Refresh tupitube.libav.patch
- Add tupitube-pkgconfig.patch and
  tupitube-fix_quazip_namespace.patch
* Thu Feb  1 2018 jengelh@inai.de
- Fix errors in description.
* Thu Feb  1 2018 aloisio@gmx.com
- Fixed runtime requirements
* Sat Jan 27 2018 aloisio@gmx.com
- Update to 0.2.10
  * Several critical bugs around the Exposure Sheet module and the
    Time Line were fixed.
  * The Color Palette interface was improved, including the
    interaction with Color Fill tools.
  * The first phase of the Sound Module implementation has been
    included to support sound files just as references to animate.
    In future versions, the sound files will be merged within the
    animation video files.
  * The Position Tween was improved by including the Undo option
    for the path edition mode.
  * The Stop Motion module was refactored to fix several bugs and
    to enhance its user experience.
- Changed name to tupitube (as per upstream renaming)
- Spec cleanup
* Tue Jun 20 2017 olaf@aepfle.de
- Update to 0.2.9
* Fri Apr  8 2016 avvissu@yandex.by
- Add Requires: plugins
* Sun Jan  3 2016 avvissu@yandex.ru
- Initial build
